# PyPierrat
My Personal Python Librairie

## Use
```bash
pip install pypierrat
```

## References
https://packaging.python.org/tutorials/packaging-projects/

## Installation

Clone repositry
```bash
git clone https://github.com/JulesPierrat/pypierrat
```

Create virtual environnement
```bash
# Create
python3 -m venv env

# Setup
pip install -r requirements.txt
```

Activate / deactivate virtual env
```bash
source env/bin/activate
deactivate
```

## Organisation

TO COMPLETE

## UPLOAD

Change number of version in the file `setup.cfg`
	
Upload to Pypi
```bash
sudo ./upload-pypi
```
